@@ -36,7 +36,7 @@ date_default_timezone_set('UTC');
  */
 class Tweeper {
 
-  private static $userAgent = "Mozilla/5.0";
+  private static $userAgent = "APIs-Google (+https://developers.google.com/webmasters/APIs-Google.html)";
   private static $maxConnectionTimeout = 5;
   private static $maxConnectionRetries = 5;
 
@@ -86,46 +86,6 @@ class Tweeper {
     return Tweeper::epochToRssDate($timestamp);
   }
 
-  /**
-   * Convert Twitter mobile date to the date format expected in a RSS document.
-   */
-  public static function twitterToRssDate($date) {
-    // Twitter uses relative timestamps in minutes for recent tweets.
-    if (preg_match('/^(\d+)m$/', $date, $matches)) {
-      $timestamp = strtotime("+" . $matches[1] . " min", time());
-      if (FALSE === $timestamp) {
-        $timestamp = 0;
-      }
-    }
-    else {
-      /*
-       * In case the time is specified put it after the date,
-       * to make it recognized by strptime().
-       */
-      if (preg_match('/(.*) - (.*)/', $date, $matches)) {
-        $date = $matches[2] . " " . $matches[1];
-      }
-
-      $timestamp = strtotime($date);
-      if (FALSE === $timestamp) {
-        $timestamp = 0;
-      }
-
-      /*
-       * The twitter mobile UI usually only specifies the month and the day, so
-       * strtotime($date) may interpret the date as being in the future.
-       *
-       * If the date is in the future it is probably in the same day but in the
-       * previous year.
-       */
-      if ($timestamp > time()) {
-        $timestamp = strtotime('-1 years', $timestamp);
-      }
-    }
-
-    return Tweeper::epochToRssDate($timestamp);
-  }
-
   /**
    * Convert string to UpperCamelCase.
    */
@@ -151,6 +111,17 @@ class Tweeper {
       }
     } while (curl_errno($ch) == CURLE_OPERATION_TIMEDOUT && ++$attempt < Tweeper::$maxConnectionRetries);
 
+    $response_code = curl_getinfo($ch, CURLINFO_RESPONSE_CODE);
+    if (FALSE === $response_code) {
+      trigger_error(curl_error($ch), E_USER_WARNING);
+      return FALSE;
+    }
+
+    if ($response_code >= 400) {
+      trigger_error("HTTP reponse code $response_code", E_USER_WARNING);
+      return FALSE;
+    }
+
     return $ret;
   }
 
@@ -349,6 +320,14 @@ class Tweeper {
     // remove it to silence an error message.
     unset($data["knobs"]);
 
+    // Stop here in case Instagram redirected to the login page, this can
+    // happen when too many consecutive requests have been made from the same
+    // IP.
+    if (array_key_exists("LoginAndSignupPage", $data["entry_data"])) {
+      trigger_error("Cannot open instagram page: redirected to Login page.\n", E_USER_WARNING);
+      return NULL;
+    }
+
     $json = json_encode($data);
 
     return Tweeper::jsonToXml($json, 'instagram');
@@ -376,6 +355,9 @@ class Tweeper {
     $get_xml_host_method = 'getXml' . Tweeper::toUpperCamelCase($host, '.');
     if (method_exists($this, $get_xml_host_method)) {
       $xml_data = call_user_func_array([$this, $get_xml_host_method], [$html]);
+      if (NULL === $xml_data) {
+        return NULL;
+      }
       $xmlDoc->loadXML($xml_data);
     }
     else {
@@ -455,15 +437,7 @@ class Tweeper {
       return NULL;
     }
 
-    // Override User-Agent for twitter.com to force it to serve the mobile UI.
-    if ($host == "twitter.com") {
-      $user_agent = "Mozilla/5.0 (Linux; U; Android 4.3; en-us; SM-N900T Build/JSS15J)";
-    }
-    else {
-      $user_agent = NULL;
-    }
-
-    $html = Tweeper::getUrlContents($src_url, $user_agent);
+    $html = Tweeper::getUrlContents($src_url);
     if (FALSE === $html) {
       trigger_error("Failed to retrieve $src_url", E_USER_WARNING);
       return NULL;
